==> vault-debug-1.15.1-1-x86_64.pkg.tar.zst: usr/src/debug/vault/pkg/mod/github.com/microsoftgraph/msgraph-sdk-go@v1.13.0/models/event_message_detail.go <==
package models

import (
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91 "github.com/microsoft/kiota-abstractions-go/serialization"
    ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e "github.com/microsoft/kiota-abstractions-go/store"
)

// EventMessageDetail 
type EventMessageDetail struct {
    // Stores model information.
    backingStore ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore
}
// NewEventMessageDetail instantiates a new eventMessageDetail and sets the default values.
func NewEventMessageDetail()(*EventMessageDetail) {
    m := &EventMessageDetail{
    }
    m.backingStore = ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStoreFactoryInstance();
    m.SetAdditionalData(make(map[string]any))
    return m
}
// CreateEventMessageDetailFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value
func CreateEventMessageDetailFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error) {
    if parseNode != nil {
        mappingValueNode, err := parseNode.GetChildNode("@odata.type")
        if err != nil {
            return nil, err
        }
        if mappingValueNode != nil {
            mappingValue, err := mappingValueNode.GetStringValue()
            if err != nil {
                return nil, err
            }
            if mappingValue != nil {
                switch *mappingValue {
                    case "#microsoft.graph.callEndedEventMessageDetail":
                        return NewCallEndedEventMessageDetail(), nil
                    case "#microsoft.graph.callRecordingEventMessageDetail":
                        return NewCallRecordingEventMessageDetail(), nil
                    case "#microsoft.graph.callStartedEventMessageDetail":
                        return NewCallStartedEventMessageDetail(), nil
                    case "#microsoft.graph.callTranscriptEventMessageDetail":
                        return NewCallTranscriptEventMessageDetail(), nil
                    case "#microsoft.graph.channelAddedEventMessageDetail":
                        return NewChannelAddedEventMessageDetail(), nil
                    case "#microsoft.graph.channelDeletedEventMessageDetail":
                        return NewChannelDeletedEventMessageDetail(), nil
                    case "#microsoft.graph.channelDescriptionUpdatedEventMessageDetail":
                        return NewChannelDescriptionUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.channelRenamedEventMessageDetail":
                        return NewChannelRenamedEventMessageDetail(), nil
                    case "#microsoft.graph.channelSetAsFavoriteByDefaultEventMessageDetail":
                        return NewChannelSetAsFavoriteByDefaultEventMessageDetail(), nil
                    case "#microsoft.graph.channelUnsetAsFavoriteByDefaultEventMessageDetail":
                        return NewChannelUnsetAsFavoriteByDefaultEventMessageDetail(), nil
                    case "#microsoft.graph.chatRenamedEventMessageDetail":
                        return NewChatRenamedEventMessageDetail(), nil
                    case "#microsoft.graph.conversationMemberRoleUpdatedEventMessageDetail":
                        return NewConversationMemberRoleUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.meetingPolicyUpdatedEventMessageDetail":
                        return NewMeetingPolicyUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.membersAddedEventMessageDetail":
                        return NewMembersAddedEventMessageDetail(), nil
                    case "#microsoft.graph.membersDeletedEventMessageDetail":
                        return NewMembersDeletedEventMessageDetail(), nil
                    case "#microsoft.graph.membersJoinedEventMessageDetail":
                        return NewMembersJoinedEventMessageDetail(), nil
                    case "#microsoft.graph.membersLeftEventMessageDetail":
                        return NewMembersLeftEventMessageDetail(), nil
                    case "#microsoft.graph.messagePinnedEventMessageDetail":
                        return NewMessagePinnedEventMessageDetail(), nil
                    case "#microsoft.graph.messageUnpinnedEventMessageDetail":
                        return NewMessageUnpinnedEventMessageDetail(), nil
                    case "#microsoft.graph.tabUpdatedEventMessageDetail":
                        return NewTabUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.teamArchivedEventMessageDetail":
                        return NewTeamArchivedEventMessageDetail(), nil
                    case "#microsoft.graph.teamCreatedEventMessageDetail":
                        return NewTeamCreatedEventMessageDetail(), nil
                    case "#microsoft.graph.teamDescriptionUpdatedEventMessageDetail":
                        return NewTeamDescriptionUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.teamJoiningDisabledEventMessageDetail":
                        return NewTeamJoiningDisabledEventMessageDetail(), nil
                    case "#microsoft.graph.teamJoiningEnabledEventMessageDetail":
                        return NewTeamJoiningEnabledEventMessageDetail(), nil
                    case "#microsoft.graph.teamRenamedEventMessageDetail":
                        return NewTeamRenamedEventMessageDetail(), nil
                    case "#microsoft.graph.teamsAppInstalledEventMessageDetail":
                        return NewTeamsAppInstalledEventMessageDetail(), nil
                    case "#microsoft.graph.teamsAppRemovedEventMessageDetail":
                        return NewTeamsAppRemovedEventMessageDetail(), nil
                    case "#microsoft.graph.teamsAppUpgradedEventMessageDetail":
                        return NewTeamsAppUpgradedEventMessageDetail(), nil
                    case "#microsoft.graph.teamUnarchivedEventMessageDetail":
                        return NewTeamUnarchivedEventMessageDetail(), nil
                }
            }
        }
    }
    return NewEventMessageDetail(), nil
}
// GetAdditionalData gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (m *EventMessageDetail) GetAdditionalData()(map[string]any) {
    val , err :=  m.backingStore.Get("additionalData")
    if err != nil {
        panic(err)
    }
    if val == nil {
        var value = make(map[string]any);
        m.SetAdditionalData(value);
    }
    return val.(map[string]any)
}
// GetBackingStore gets the backingStore property value. Stores model information.
func (m *EventMessageDetail) GetBackingStore()(ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore) {
    return m.backingStore
}
// GetFieldDeserializers the deserialization information for the current model
func (m *EventMessageDetail) GetFieldDeserializers()(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error)) {
    res := make(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error))
    res["@odata.type"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetOdataType(val)
        }
        return nil
    }
    return res
}
// GetOdataType gets the @odata.type property value. The OdataType property
func (m *EventMessageDetail) GetOdataType()(*string) {
    val, err := m.GetBackingStore().Get("odataType")
    if err != nil {
        panic(err)
    }
    if val != nil {
        return val.(*string)
    }
    return nil
}
// Serialize serializes information the current object
func (m *EventMessageDetail) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter)(error) {
    {
        err := writer.WriteStringValue("@odata.type", m.GetOdataType())
        if err != nil {
            return err
        }
    }
    {
        err := writer.WriteAdditionalData(m.GetAdditionalData())
        if err != nil {
            return err
        }
    }
    return nil
}
// SetAdditionalData sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (m *EventMessageDetail) SetAdditionalData(value map[string]any)() {
    err := m.GetBackingStore().Set("additionalData", value)
    if err != nil {
        panic(err)
    }
}
// SetBackingStore sets the backingStore property value. Stores model information.
func (m *EventMessageDetail) SetBackingStore(value ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)() {
    m.backingStore = value
}
// SetOdataType sets the @odata.type property value. The OdataType property
func (m *EventMessageDetail) SetOdataType(value *string)() {
    err := m.GetBackingStore().Set("odataType", value)
    if err != nil {
        panic(err)
    }
}
// EventMessageDetailable 
type EventMessageDetailable interface {
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.AdditionalDataHolder
    ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackedModel
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
    GetBackingStore()(ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)
    GetOdataType()(*string)
    SetBackingStore(value ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)()
    SetOdataType(value *string)()
}

==> vault-debug-1.16.2-1-x86_64.pkg.tar.zst: usr/src/debug/vault/pkg/mod/github.com/microsoftgraph/msgraph-sdk-go@v1.32.0/models/event_message_detail.go <==
package models

import (
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91 "github.com/microsoft/kiota-abstractions-go/serialization"
    ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e "github.com/microsoft/kiota-abstractions-go/store"
)

// EventMessageDetail 
type EventMessageDetail struct {
    // Stores model information.
    backingStore ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore
}
// NewEventMessageDetail instantiates a new eventMessageDetail and sets the default values.
func NewEventMessageDetail()(*EventMessageDetail) {
    m := &EventMessageDetail{
    }
    m.backingStore = ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStoreFactoryInstance();
    m.SetAdditionalData(make(map[string]any))
    return m
}
// CreateEventMessageDetailFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value
func CreateEventMessageDetailFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error) {
    if parseNode != nil {
        mappingValueNode, err := parseNode.GetChildNode("@odata.type")
        if err != nil {
            return nil, err
        }
        if mappingValueNode != nil {
            mappingValue, err := mappingValueNode.GetStringValue()
            if err != nil {
                return nil, err
            }
            if mappingValue != nil {
                switch *mappingValue {
                    case "#microsoft.graph.callEndedEventMessageDetail":
                        return NewCallEndedEventMessageDetail(), nil
                    case "#microsoft.graph.callRecordingEventMessageDetail":
                        return NewCallRecordingEventMessageDetail(), nil
                    case "#microsoft.graph.callStartedEventMessageDetail":
                        return NewCallStartedEventMessageDetail(), nil
                    case "#microsoft.graph.callTranscriptEventMessageDetail":
                        return NewCallTranscriptEventMessageDetail(), nil
                    case "#microsoft.graph.channelAddedEventMessageDetail":
                        return NewChannelAddedEventMessageDetail(), nil
                    case "#microsoft.graph.channelDeletedEventMessageDetail":
                        return NewChannelDeletedEventMessageDetail(), nil
                    case "#microsoft.graph.channelDescriptionUpdatedEventMessageDetail":
                        return NewChannelDescriptionUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.channelRenamedEventMessageDetail":
                        return NewChannelRenamedEventMessageDetail(), nil
                    case "#microsoft.graph.channelSetAsFavoriteByDefaultEventMessageDetail":
                        return NewChannelSetAsFavoriteByDefaultEventMessageDetail(), nil
                    case "#microsoft.graph.channelUnsetAsFavoriteByDefaultEventMessageDetail":
                        return NewChannelUnsetAsFavoriteByDefaultEventMessageDetail(), nil
                    case "#microsoft.graph.chatRenamedEventMessageDetail":
                        return NewChatRenamedEventMessageDetail(), nil
                    case "#microsoft.graph.conversationMemberRoleUpdatedEventMessageDetail":
                        return NewConversationMemberRoleUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.meetingPolicyUpdatedEventMessageDetail":
                        return NewMeetingPolicyUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.membersAddedEventMessageDetail":
                        return NewMembersAddedEventMessageDetail(), nil
                    case "#microsoft.graph.membersDeletedEventMessageDetail":
                        return NewMembersDeletedEventMessageDetail(), nil
                    case "#microsoft.graph.membersJoinedEventMessageDetail":
                        return NewMembersJoinedEventMessageDetail(), nil
                    case "#microsoft.graph.membersLeftEventMessageDetail":
                        return NewMembersLeftEventMessageDetail(), nil
                    case "#microsoft.graph.messagePinnedEventMessageDetail":
                        return NewMessagePinnedEventMessageDetail(), nil
                    case "#microsoft.graph.messageUnpinnedEventMessageDetail":
                        return NewMessageUnpinnedEventMessageDetail(), nil
                    case "#microsoft.graph.tabUpdatedEventMessageDetail":
                        return NewTabUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.teamArchivedEventMessageDetail":
                        return NewTeamArchivedEventMessageDetail(), nil
                    case "#microsoft.graph.teamCreatedEventMessageDetail":
                        return NewTeamCreatedEventMessageDetail(), nil
                    case "#microsoft.graph.teamDescriptionUpdatedEventMessageDetail":
                        return NewTeamDescriptionUpdatedEventMessageDetail(), nil
                    case "#microsoft.graph.teamJoiningDisabledEventMessageDetail":
                        return NewTeamJoiningDisabledEventMessageDetail(), nil
                    case "#microsoft.graph.teamJoiningEnabledEventMessageDetail":
                        return NewTeamJoiningEnabledEventMessageDetail(), nil
                    case "#microsoft.graph.teamRenamedEventMessageDetail":
                        return NewTeamRenamedEventMessageDetail(), nil
                    case "#microsoft.graph.teamsAppInstalledEventMessageDetail":
                        return NewTeamsAppInstalledEventMessageDetail(), nil
                    case "#microsoft.graph.teamsAppRemovedEventMessageDetail":
                        return NewTeamsAppRemovedEventMessageDetail(), nil
                    case "#microsoft.graph.teamsAppUpgradedEventMessageDetail":
                        return NewTeamsAppUpgradedEventMessageDetail(), nil
                    case "#microsoft.graph.teamUnarchivedEventMessageDetail":
                        return NewTeamUnarchivedEventMessageDetail(), nil
                }
            }
        }
    }
    return NewEventMessageDetail(), nil
}
// GetAdditionalData gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (m *EventMessageDetail) GetAdditionalData()(map[string]any) {
    val , err :=  m.backingStore.Get("additionalData")
    if err != nil {
        panic(err)
    }
    if val == nil {
        var value = make(map[string]any);
        m.SetAdditionalData(value);
    }
    return val.(map[string]any)
}
// GetBackingStore gets the BackingStore property value. Stores model information.
func (m *EventMessageDetail) GetBackingStore()(ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore) {
    return m.backingStore
}
// GetFieldDeserializers the deserialization information for the current model
func (m *EventMessageDetail) GetFieldDeserializers()(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error)) {
    res := make(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error))
    res["@odata.type"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetStringValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetOdataType(val)
        }
        return nil
    }
    return res
}
// GetOdataType gets the @odata.type property value. The OdataType property
func (m *EventMessageDetail) GetOdataType()(*string) {
    val, err := m.GetBackingStore().Get("odataType")
    if err != nil {
        panic(err)
    }
    if val != nil {
        return val.(*string)
    }
    return nil
}
// Serialize serializes information the current object
func (m *EventMessageDetail) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter)(error) {
    {
        err := writer.WriteStringValue("@odata.type", m.GetOdataType())
        if err != nil {
            return err
        }
    }
    {
        err := writer.WriteAdditionalData(m.GetAdditionalData())
        if err != nil {
            return err
        }
    }
    return nil
}
// SetAdditionalData sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
func (m *EventMessageDetail) SetAdditionalData(value map[string]any)() {
    err := m.GetBackingStore().Set("additionalData", value)
    if err != nil {
        panic(err)
    }
}
// SetBackingStore sets the BackingStore property value. Stores model information.
func (m *EventMessageDetail) SetBackingStore(value ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)() {
    m.backingStore = value
}
// SetOdataType sets the @odata.type property value. The OdataType property
func (m *EventMessageDetail) SetOdataType(value *string)() {
    err := m.GetBackingStore().Set("odataType", value)
    if err != nil {
        panic(err)
    }
}
// EventMessageDetailable 
type EventMessageDetailable interface {
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.AdditionalDataHolder
    ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackedModel
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
    GetBackingStore()(ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)
    GetOdataType()(*string)
    SetBackingStore(value ie8677ce2c7e1b4c22e9c3827ecd078d41185424dd9eeb92b7d971ed2d49a392e.BackingStore)()
    SetOdataType(value *string)()
}
